function varargout = assemMat_2DLFE(Mesh,EHandle,varargin)

    % Initialize constants
    nElements = size(Mesh.Elements,1);
    nCoords = size(Mesh.Coordinates,1);
  
    % Preallocate memory
    I = zeros(36*nElements,1);
    J = zeros(36*nElements,1);
    A = zeros(36*nElements,1);
  
    % Check for element flags
    if(isfield(Mesh,'ElemFlag')),
        flags = Mesh.ElemFlag; 
    else
        flags = zeros(nElements,1);
    end

    % Assemble element contributions
    loc = 1:36;
    for i = 1:nElements
    
        % Extract vertices of current element
        idx = Mesh.Elements(i,:);
        Vertices = Mesh.Coordinates(idx,:);
        idx = [idx, idx + nCoords];
      
        % Compute element contributions
        Aloc = EHandle(Vertices,flags(i),varargin{:});
   
        % Add contributions to stiffness matrix
        I(loc) = set_Rows(idx,6);
        J(loc) = set_Cols(idx,6);
        A(loc) = Aloc(:);
        loc = loc+36;
    
    end
  
    % Assign output arguments
    if(nargout > 1)
        varargout{1} = I;
        varargout{2} = J;
        varargout{3} = A;
    else
        varargout{1} = sparse(I,J,A);      
    end
  
end
